@@ -1,5 +1,5 @@
 """Top-level package for safe-reboot."""
 
 __author__ = """Sebastian Wallat"""
-__email__ = 'sebastian@wallat.io'
-__version__ = '0.1.2'
+__email__ = 'devwallat@gmail.com'
+__version__ = '0.2.0'
